#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using HeuristicLab.PluginInfrastructure;

namespace HeuristicLab.Problems.DataAnalysis {
  public static class DatasetExtensions {
    public static IEnumerable<double> GetVectorEnumerable(this Dataset ds, IEnumerable<string> targetVariables, IEnumerable<int> rows) {
      var vars = targetVariables.ToArray();
      var values = (from var in vars
                    select ds.GetReadOnlyDoubleValues(var))
        .ToArray();

      foreach (var r in rows) {
        for (int i = 0; i < values.Length; i++)
          yield return values[i][r];
      }
    }

    public static IEnumerable<T> TakeEvery<T>(this IEnumerable<T> xs, int nth) {
      int i = 0;
      foreach (var x in xs) {
        if (i % nth == 0) yield return x;
        i++;
      }
    }
  }
}
